AsyncDispatcher

Struct AsyncDispatcher 

pub struct AsyncDispatcher(/* private fields */);
A reference to a dispatcher that supports the v4 async api’s reference counting operations, and so can be held safely without a lifetime.

Implementations

Source

impl AsyncDispatcher

pub fn new(dispatcher: &impl AsAsyncDispatcherRef) -> AsyncDispatcher

Converts from something that implements AsAsyncDispatcherRef to an AsyncDispatcher if it implements the v4 async api’s reference counting.

Panics

This will panic if the implementation does not support reference counting. If you need to be able to deal with a dispatcher that might not implement this api, you can use AsyncDispatcher::new.

pub fn try_new( dispatcher: &impl AsAsyncDispatcherRef, ) -> Result<AsyncDispatcher, Status>

Converts from something that implements AsAsyncDispatcherRef to an AsyncDispatcher if it implements the v4 async api’s reference counting.

Returns [Status::UNSUPPORTED] if the dispatcher does not support refcounting.